@@ -33,28 +33,28 @@
 #include "src/tools/launcher/applauncherwidget.h"
 #endif
 
-void
-showOpenWithMenu(const QPixmap& capture)
+void showOpenWithMenu(const QPixmap& capture)
 {
 #if defined(Q_OS_WIN)
-  QString tempFile =
-    FileNameHandler().generateAbsolutePath(QDir::tempPath()) + ".png";
-  bool ok = capture.save(tempFile);
-  if (!ok) {
-    QMessageBox::about(nullptr,
-                       QObject::tr("Error"),
-                       QObject::tr("Unable to write in") + QDir::tempPath());
-    return;
-  }
+    QString tempFile =
+      FileNameHandler().generateAbsolutePath(QDir::tempPath()) + ".png";
+    bool ok = capture.save(tempFile);
+    if (!ok) {
+        QMessageBox::about(nullptr,
+                           QObject::tr("Error"),
+                           QObject::tr("Unable to write in") +
+                             QDir::tempPath());
+        return;
+    }
 
-  OPENASINFO info;
-  auto wStringFile = tempFile.replace("/", "\\").toStdWString();
-  info.pcszFile = wStringFile.c_str();
-  info.pcszClass = nullptr;
-  info.oaifInFlags = OAIF_ALLOW_REGISTRATION | OAIF_EXEC;
-  SHOpenWithDialog(nullptr, &info);
+    OPENASINFO info;
+    auto wStringFile = tempFile.replace("/", "\\").toStdWString();
+    info.pcszFile = wStringFile.c_str();
+    info.pcszClass = nullptr;
+    info.oaifInFlags = OAIF_ALLOW_REGISTRATION | OAIF_EXEC;
+    SHOpenWithDialog(nullptr, &info);
 #else
-  auto w = new AppLauncherWidget(capture);
-  w->show();
+    auto w = new AppLauncherWidget(capture);
+    w->show();
 #endif
 }
