@@ -22,45 +22,38 @@ MoveTool::MoveTool(QObject* parent)
   : AbstractActionTool(parent)
 {}
 
-bool
-MoveTool::closeOnButtonPressed() const
+bool MoveTool::closeOnButtonPressed() const
 {
-  return false;
+    return false;
 }
 
-QIcon
-MoveTool::icon(const QColor& background, bool inEditor) const
+QIcon MoveTool::icon(const QColor& background, bool inEditor) const
 {
-  Q_UNUSED(inEditor);
-  return QIcon(iconPath(background) + "cursor-move.svg");
+    Q_UNUSED(inEditor);
+    return QIcon(iconPath(background) + "cursor-move.svg");
 }
-QString
-MoveTool::name() const
+QString MoveTool::name() const
 {
-  return tr("Move");
+    return tr("Move");
 }
 
-ToolType
-MoveTool::nameID() const
+ToolType MoveTool::nameID() const
 {
-  return ToolType::MOVE;
+    return ToolType::MOVE;
 }
 
-QString
-MoveTool::description() const
+QString MoveTool::description() const
 {
-  return tr("Move the selection area");
+    return tr("Move the selection area");
 }
 
-CaptureTool*
-MoveTool::copy(QObject* parent)
+CaptureTool* MoveTool::copy(QObject* parent)
 {
-  return new MoveTool(parent);
+    return new MoveTool(parent);
 }
 
-void
-MoveTool::pressed(const CaptureContext& context)
+void MoveTool::pressed(const CaptureContext& context)
 {
-  Q_UNUSED(context);
-  emit requestAction(REQ_MOVE_MODE);
+    Q_UNUSED(context);
+    emit requestAction(REQ_MOVE_MODE);
 }
