@@ -17,28 +17,22 @@
 
 #include "colorutils.h"
 
-inline qreal
-getColorLuma(const QColor& c)
+inline qreal getColorLuma(const QColor& c)
 {
-  return 0.30 * c.redF() + 0.59 * c.greenF() + 0.11 * c.blueF();
+    return 0.30 * c.redF() + 0.59 * c.greenF() + 0.11 * c.blueF();
 }
 
-bool
-ColorUtils::colorIsDark(const QColor& c)
+bool ColorUtils::colorIsDark(const QColor& c)
 {
-  bool isWhite = false;
-  if (getColorLuma(c) <= 0.60) {
-    isWhite = true;
-  }
-  return isWhite;
+    // when luma <= 0.5, we considor it as a dark color
+    return getColorLuma(c) <= 0.5;
 }
 
-QColor
-ColorUtils::contrastColor(const QColor& c)
+QColor ColorUtils::contrastColor(const QColor& c)
 {
-  int change = colorIsDark(c) ? 30 : -45;
+    int change = colorIsDark(c) ? 30 : -45;
 
-  return QColor(qBound(0, c.red() + change, 255),
-                qBound(0, c.green() + change, 255),
-                qBound(0, c.blue() + change, 255));
+    return QColor(qBound(0, c.red() + change, 255),
+                  qBound(0, c.green() + change, 255),
+                  qBound(0, c.blue() + change, 255));
 }
