@@ -20,29 +20,27 @@
 #include <QDir>
 #include <QFileInfo>
 
-const QString
-PathInfo::whiteIconPath()
+const QString PathInfo::whiteIconPath()
 {
-  return QStringLiteral(":/img/material/white/");
+    return QStringLiteral(":/img/material/white/");
 }
 
-const QString
-PathInfo::blackIconPath()
+const QString PathInfo::blackIconPath()
 {
-  return QStringLiteral(":/img/material/black/");
+    return QStringLiteral(":/img/material/black/");
 }
 
-QStringList
-PathInfo::translationsPaths()
+QStringList PathInfo::translationsPaths()
 {
-  QString binaryPath = QFileInfo(qApp->applicationDirPath()).absoluteFilePath();
-  QString trPath = QDir::toNativeSeparators(binaryPath + "/translations");
+    QString binaryPath =
+      QFileInfo(qApp->applicationDirPath()).absoluteFilePath();
+    QString trPath = QDir::toNativeSeparators(binaryPath + "/translations");
 #if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
-  return QStringList()
-         << QStringLiteral(APP_PREFIX) + "/share/flameshot/translations"
-         << trPath << QStringLiteral("/usr/share/flameshot/translations")
-         << QStringLiteral("/usr/local/share/flameshot/translations");
+    return QStringList()
+           << QStringLiteral(APP_PREFIX) + "/share/flameshot/translations"
+           << trPath << QStringLiteral("/usr/share/flameshot/translations")
+           << QStringLiteral("/usr/local/share/flameshot/translations");
 #elif defined(Q_OS_WIN)
-  return QStringList() << trPath;
+    return QStringList() << trPath;
 #endif
 }
